@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 11291 2009-02-17 00:21:22Z callum $
+ $Id: battstat_applet.c 11390 2009-03-19 23:33:42Z callum $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1018,11 +1018,11 @@ check_for_updates( gpointer data )
   {
     int timeout;
 
-    /* if on AC and not even driven scale back the polls to once every 10 */
+    /* if on AC and not event driven scale back the polls to once every 10 */
     if (info.on_ac_power)
-      timeout = 10000;
+      timeout = 10;
     else
-      timeout = 1000;
+      timeout = 2;
 
     if (timeout != battstat->timeout)
     {
@@ -1031,7 +1031,7 @@ check_for_updates( gpointer data )
       if (battstat->timeout_id)
         g_source_remove (battstat->timeout_id);
 
-      battstat->timeout_id = g_timeout_add (battstat->timeout,
+      battstat->timeout_id = g_timeout_add_seconds (battstat->timeout,
                                             check_for_updates,
                                             battstat);
     }
