@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: power-management.c 10052 2006-11-15 16:57:08Z kmaraas $
+ $Id: power-management.c 11289 2009-02-16 23:48:56Z callum $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -119,37 +119,37 @@ initialise_test( void )
 
   box = GTK_BOX( gtk_vbox_new( 5, FALSE ) );
 
-  gtk_box_pack_start_defaults( box, gtk_label_new( "percent" ) );
+  gtk_box_pack_start( box, gtk_label_new( "percent" ), TRUE, TRUE, 0);
   w = gtk_spin_button_new_with_range( -1.0, 100.0, 1 );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON( w ), 50.0 );
   g_signal_connect( G_OBJECT( w ), "value-changed",
                     G_CALLBACK( test_update_integer ), &test_status.percent );
-  gtk_box_pack_start_defaults( box, w );
+  gtk_box_pack_start( box, w, TRUE, TRUE, 0 );
 
-  gtk_box_pack_start_defaults( box, gtk_label_new( "minutes" ) );
+  gtk_box_pack_start( box, gtk_label_new( "minutes" ), TRUE, TRUE, 0);
   w = gtk_spin_button_new_with_range( -1.0, 1000.0, 1 );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON( w ), 180.0 );
   g_signal_connect( G_OBJECT( w ), "value-changed",
                     G_CALLBACK( test_update_integer ), &test_status.minutes );
-  gtk_box_pack_start_defaults( box, w );
+  gtk_box_pack_start( box, w, TRUE, TRUE, 0);
 
 
   w = gtk_toggle_button_new_with_label( "on_ac_power" );
   g_signal_connect( G_OBJECT( w ), "toggled",
                     G_CALLBACK( test_update_boolean ),
                     &test_status.on_ac_power );
-  gtk_box_pack_start_defaults( box, w );
+  gtk_box_pack_start( box, w, TRUE, TRUE, 0);
 
   w = gtk_toggle_button_new_with_label( "charging" );
   g_signal_connect( G_OBJECT( w ), "toggled",
                     G_CALLBACK( test_update_boolean ), &test_status.charging );
-  gtk_box_pack_start_defaults( box, w );
+  gtk_box_pack_start( box, w, TRUE, TRUE, 0);
 
   w = gtk_toggle_button_new_with_label( "present" );
   gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( w ), TRUE );
   g_signal_connect( G_OBJECT( w ), "toggled",
                     G_CALLBACK( test_update_boolean ), &test_status.present );
-  gtk_box_pack_start_defaults( box, w );
+  gtk_box_pack_start( box, w, TRUE, TRUE, 0);
 
   w = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_container_add( GTK_CONTAINER( w ), GTK_WIDGET( box ) );
@@ -430,6 +430,9 @@ power_management_getinfo( BatteryStatus *status )
 const char *
 power_management_initialise (int no_hal, void (*callback) (void))
 {
+#ifdef __linux__
+  struct stat statbuf;
+#endif
 #ifdef HAVE_HAL
   char *err;
 
@@ -451,7 +454,6 @@ power_management_initialise (int no_hal, void (*callback) (void))
 #endif
     
 #ifdef __linux__
-  struct stat statbuf;
 
   if (acpi_linux_init(&acpiinfo)) {
     using_acpi = TRUE;
