@@ -22,8 +22,6 @@
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE 1
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
 #include <libwnck/libwnck.h>
 #include <string.h>
 
@@ -35,6 +33,8 @@
 /* Stop gcc complaining about xmlChar's signedness */
 #define XML_CHAR(str) ((xmlChar *) (str))
 
+static gboolean save_scheduled = FALSE;
+
 static void response_cb (GtkWidget *dialog, gint id, gpointer data);
 
 /* Based on a function found in wnck */
@@ -79,7 +79,7 @@ buffer_changed (GtkTextBuffer *buffer, gpointer data)
 	   the timer triggers, we will save the buffer if there have
 	   been no subsequent changes.  */
 	++stickynotes->last_timeout_data;
-	g_timeout_add (1000 * 10, (GSourceFunc) timeout_happened,
+	g_timeout_add_seconds (10, (GSourceFunc) timeout_happened,
 		       GUINT_TO_POINTER (stickynotes->last_timeout_data));
 }
 
@@ -102,13 +102,19 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	gtk_window_set_decorated (GTK_WINDOW (note->w_window), FALSE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (note->w_window), TRUE);
 	gtk_window_set_skip_pager_hint (GTK_WINDOW (note->w_window), TRUE);
+	gtk_widget_add_events (note->w_window, GDK_BUTTON_PRESS_MASK);
 
 	note->w_title = GTK_WIDGET (gtk_builder_get_object (builder, "title_label"));
 	note->w_body = GTK_WIDGET (gtk_builder_get_object (builder, "body_text"));
 	note->w_lock = GTK_WIDGET (gtk_builder_get_object (builder, "lock_button"));
+	gtk_widget_add_events (note->w_lock, GDK_BUTTON_PRESS_MASK);
+
 	note->w_close = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
+	gtk_widget_add_events (note->w_close, GDK_BUTTON_PRESS_MASK);
 	note->w_resize_se = GTK_WIDGET (gtk_builder_get_object (builder, "resize_se_box"));
+	gtk_widget_add_events (note->w_resize_se, GDK_BUTTON_PRESS_MASK);
 	note->w_resize_sw = GTK_WIDGET (gtk_builder_get_object (builder, "resize_sw_box"));
+	gtk_widget_add_events (note->w_resize_sw, GDK_BUTTON_PRESS_MASK);
 	
 	note->img_lock = GTK_IMAGE (gtk_builder_get_object (builder,
 	                "lock_img"));
@@ -196,13 +202,26 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	gtk_widget_realize (note->w_window);
 
-	/* gnome_popup_menu_*() are deprecated. Rewrite to use gtk_menu_popup_*()? */
 	/* Connect a popup menu to all buttons and title */
-	gnome_popup_menu_attach(note->w_menu, note->w_window, note);
-	gnome_popup_menu_attach(note->w_menu, note->w_lock, note);
-	gnome_popup_menu_attach(note->w_menu, note->w_close, note);
-	gnome_popup_menu_attach(note->w_menu, note->w_resize_se, note);
-	gnome_popup_menu_attach(note->w_menu, note->w_resize_sw, note);
+	/* GtkBuilder holds and drops the references to all the widgets it 
+	 * creates for as long as it exist (GtkBuilder). Hence in our callback
+	 * we would have an invalid GtkMenu. We need to ref it.
+	 */
+	g_object_ref (note->w_menu);
+	g_signal_connect (G_OBJECT (note->w_window), "button-press-event",
+			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
+
+	g_signal_connect (G_OBJECT (note->w_lock), "button-press-event",
+			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
+
+	g_signal_connect (G_OBJECT (note->w_close), "button-press-event",
+			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
+
+	g_signal_connect (G_OBJECT (note->w_resize_se), "button-press-event",
+			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
+
+	g_signal_connect (G_OBJECT (note->w_resize_sw), "button-press-event",
+			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
 
 	/* Connect a properties dialog to the note */
 	gtk_window_set_transient_for (GTK_WINDOW(note->w_properties),
@@ -352,7 +371,10 @@ static void
 response_cb (GtkWidget *dialog, gint id, gpointer data)
 {
         if (id == GTK_RESPONSE_HELP)
-                gnome_help_display ("stickynotes_applet", "stickynotes-settings-individual", NULL);
+		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+				"ghelp:stickynotes_applet?stickynotes-settings-individual",
+				gtk_get_current_event_time (),
+				NULL);
         else
                 gtk_widget_hide (dialog);
 }
@@ -716,7 +738,7 @@ void stickynotes_remove(StickyNote *note)
 
 /* Save all sticky notes in an XML configuration file */
 void
-stickynotes_save (void)
+stickynotes_save_now (void)
 {
 	WnckScreen *wnck_screen;
 	const gchar *title;
@@ -821,6 +843,18 @@ stickynotes_save (void)
 	}
 	
 	xmlFreeDoc(doc);
+
+	save_scheduled = FALSE;
+}
+
+void
+stickynotes_save (void)
+{
+  /* If a save isn't already schedules, save everything a minute from now. */
+  if (!save_scheduled) {
+    g_timeout_add_seconds (60, (GSourceFunc) stickynotes_save_now, NULL);
+    save_scheduled = TRUE;
+  }
 }
 
 /* Load all sticky notes from an XML configuration file */
