@@ -23,10 +23,7 @@
 #include "stickynotes_applet_callbacks.h"
 #include "stickynotes.h"
 
-#include <gtk/gtkiconfactory.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-icon-theme.h>
-#include <libgnomeui/gnome-window-icon.h>
+#include <gtk/gtk.h>
 
 StickyNotes *stickynotes = NULL;
 
@@ -122,7 +119,6 @@ stickynotes_make_prelight_icon (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 void
 stickynotes_applet_init (PanelApplet *panel_applet)
 {	
-	GnomeClient *client;
 	int timeout;
 
 	stickynotes = g_new(StickyNotes, 1);
@@ -153,6 +149,7 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	stickynotes_make_prelight_icon (stickynotes->icon_prelight,
 			stickynotes->icon_normal, 30);
 	stickynotes->gconf = gconf_client_get_default();
+	stickynotes->visible = TRUE;
 
 	stickynotes_applet_init_icons();
 	stickynotes_applet_init_prefs();
@@ -166,14 +163,6 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	gconf_client_notify_add (stickynotes->gconf, GCONF_PATH "/settings",
 			(GConfClientNotifyFunc) preferences_apply_cb,
 			NULL, NULL, NULL);
-
-	client = gnome_master_client ();
-	gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
-
-	/* The help suggests this is automatic, but that seems to not be
-	 * the case here. */
-	gnome_client_connect (client);
-	gnome_client_flush (client);
 	
 	/* Load sticky notes */
 	stickynotes_load (gtk_widget_get_screen (GTK_WIDGET (panel_applet)));
@@ -387,8 +376,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	/* Connect all signals for applet management */
 	g_signal_connect(G_OBJECT(applet->w_applet), "button-press-event",
 			G_CALLBACK(applet_button_cb), applet);
-	g_signal_connect(G_OBJECT(applet->w_applet), "button-release-event",
-			G_CALLBACK(applet_button_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "key-press-event",
 			G_CALLBACK(applet_key_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "focus-in-event",
